@@ -1,6 +1,6 @@
 package Getopt::EX::LabeledParam;
 
-our $VERSION = "2.2.2";
+our $VERSION = "2.3.1";
 
 use v5.14;
 use warnings;
@@ -196,18 +196,18 @@ Getopt::EX::LabeledParam - Labeled parameter handling
 
 =head1 DESCRIPTION
 
-This module implements super class of L<Getopt::EX::Colormap>.
+This module implements the super class of L<Getopt::EX::Colormap>.
 
-Parameters can be given in two ways: one in labeled table, and one in
+Parameters can be given in two ways: one as a labeled table, and one as an
 indexed list.
 
-Handler maintains hash and list objects, and labeled values are stored
-in hash, non-label values are in list automatically.  User can mix
+The handler maintains hash and list objects, and labeled values are stored
+in the hash, while non-label values are in the list automatically.  Users can mix
 both specifications.
 
-When the value field has a special form of function call,
-L<Getopt::EX::Func> object is created and stored for that entry.  See
-L<FUNCTION SPEC> section in L<Getopt::EX::Colormap> for more detail.
+When the value field has a special form of a function call, a
+L<Getopt::EX::Func> object is created and stored for that entry.  See the
+L<FUNCTION SPEC> section in L<Getopt::EX::Colormap> for more details.
 
 =head2 HASH
 
@@ -215,7 +215,7 @@ Basically, labeled parameter is defined by B<LABEL>=I<VALUE> notation:
 
     FILE=R
 
-Definition can be connected by comma (C<,>):
+Definitions can be connected by commas (C<,>):
 
     FILE=R,LINE=G
 
@@ -223,9 +223,9 @@ Multiple labels can be set for same value:
 
     FILE=LINE=TEXT=R
 
-Wildcard C<*> and C<?> can be used in label name, and they matches
-existing hash key name.  If labels C<OLD_FILE> and C<NEW_FILE> exists
-in hash,
+Wildcards C<*> and C<?> can be used in label names, and they match
+existing hash key names.  If labels C<OLD_FILE> and C<NEW_FILE> exist
+in the hash,
 
     *FILE=R
 
@@ -233,23 +233,23 @@ and
 
     OLD_FILE=NEW_FILE=R
 
-produces same result.
+produces the same result.
 
-If B<VALUE> part start with plus (C<+>) character, it is appended to
-current value.  At this time, C<CONCAT> string is inserted before
-additional string.  Default C<CONCAT> strings is empty, so use
-configure method to set.  If B<VALUE> part start with minus (C<->)
-character, following characters are deleted from the current value.
+If the B<VALUE> part starts with a plus (C<+>) character, it is appended to the
+current value.  At this time, the C<CONCAT> string is inserted before the
+additional string.  The default C<CONCAT> string is empty, so use the
+configure method to set it.  If the B<VALUE> part starts with a minus (C<->)
+character, the following characters are deleted from the current value.
 
 =head2 LIST
 
-If B<LABEL>= part is omitted, values are treated anonymous list and
-stored in list object.  For example,
+If the B<LABEL>= part is omitted, values are treated as an anonymous list and
+stored in the list object.  For example,
 
     R,G,B,C,M,Y
 
-makes six entries in the list.  The list object is accessed by index,
-rather than label.
+makes six entries in the list.  The list object is accessed by index
+rather than by label.
 
 =head1 METHODS
 
@@ -265,37 +265,37 @@ rather than label.
 
 =item B<LIST> =E<gt> I<listref>
 
-B<HASH> and B<LIST> reference can be set by B<new> or B<configure>
-method.  You can provide default setting of hash and list, and it is
-usually easier to access those values directly, rather than through
+B<HASH> and B<LIST> references can be set by the B<new> or B<configure>
+method.  You can provide default settings for the hash and list, and it is
+usually easier to access those values directly rather than through
 class methods.
 
 =item B<NEWLABEL> =E<gt> 0/1
 
-By default, B<load_params> does not create new entry in hash table,
-and absent label is ignored.  Setting <NEWLABEL> parameter true makes
-it possible create a new hash entry.
+By default, B<load_params> does not create a new entry in the hash table,
+and absent labels are ignored.  Setting the B<NEWLABEL> parameter to true makes
+it possible to create a new hash entry.
 
 =item B<CONCAT> =E<gt> I<string>
 
-Set concatenation string inserted before appending string.
+Set the concatenation string inserted before appending a string.
 
 =item B<RESET> =E<gt> I<string>
 
-Set B<reset> mark.  Undefined by default.  If this reset string is
+Set the B<reset> mark.  Undefined by default.  If this reset string is
 found in a list-type argument, the list is reset to empty.
 
 =back
 
 =item B<load_params> I<option>
 
-Load option list into the object.
+Load the option list into the object.
 
 =item B<append> HASHREF or LIST
 
-Provide simple interface to append colormap hash or color list.  If a
-hash reference is given, all entry of the hash is appended to the
-colormap.  Otherwise, they are appended anonymous color list.
+Provides a simple interface to append a colormap hash or color list.  If a
+hash reference is given, all entries of the hash are appended to the
+colormap.  Otherwise, they are appended to the anonymous color list.
 
 =back
 
