@@ -1,6 +1,6 @@
 package Getopt::EX::Long;
 
-our $VERSION = "2.2.2";
+our $VERSION = "2.3.1";
 
 use v5.14;
 use warnings;
@@ -174,30 +174,30 @@ Getopt::EX::Long - Getopt::Long compatible glue module
 
 =head1 DESCRIPTION
 
-L<Getopt::EX::Long> is almost compatible to L<Getopt::Long> and you
-can just replace module declaration and it should work just same as
-before (See L<INCOMPATIBILITY> section).
+L<Getopt::EX::Long> is almost compatible with L<Getopt::Long> and you
+can just replace the module declaration and it should work the same as
+before (see the L<INCOMPATIBILITY> section).
 
-Besides working same, user can define their own option aliases and
-write dynamically loaded extension module.  If the command name is
+Besides working the same, users can define their own option aliases and
+write dynamically loaded extension modules.  If the command name is
 I<example>,
 
     ~/.examplerc
 
-file is loaded by default.  In this rc file, user can define their own
-option with macro processing.  This is useful when the command takes
+file is loaded by default.  In this rc file, users can define their own
+options with macro processing.  This is useful when the command takes
 complicated arguments.
 
-Also, special command option preceded by B<-M> is taken and
-corresponding perl module is loaded.  Module is assumed under the
+Also, special command options preceded by B<-M> are recognized and the
+corresponding Perl module is loaded.  The module is assumed to be under a
 specific base class.  For example,
 
     % example -Mfoo
 
 will load C<App::example::foo> module, by default.
 
-This module is normal perl module, so user can write any kind of
-program.  If the module is specified with initial function call, it is
+This module is a normal Perl module, so users can write any kind of
+program.  If the module is specified with an initial function call, it is
 called at the beginning of command execution.  Suppose that the
 module I<foo> is specified like this:
 
@@ -206,35 +206,35 @@ module I<foo> is specified like this:
 Then, after the module B<foo> is loaded, function I<bar> is called
 with the parameter I<baz> which has value 100.
 
-If the module includes C<__DATA__> section, it is interpreted just
-same as rc file.  So you can define arbitrary option there.  Combined
-with startup function call described above, it is possible to control
-module behavior by user defined option.
+If the module includes a C<__DATA__> section, it is interpreted just the
+same as an rc file.  So you can define arbitrary options there.  Combined
+with the startup function call described above, it is possible to control
+module behavior by user-defined options.
 
-As for start-up file and Module specification, read
-L<Getopt::EX::Module> document for detail.
+For details about startup files and module specification, read the
+L<Getopt::EX::Module> documentation.
 
 =head1 CONFIG OPTIONS
 
-Config options are set by B<Getopt::ExConfigure> or B<exconfig>
-parameter for B<Getopt::EX::Long::Parser::new> method.
+Config options are set by B<Getopt::ExConfigure> or the B<exconfig>
+parameter for the B<Getopt::EX::Long::Parser::new> method.
 
 =over 4
 
 =item AUTO_DEFAULT
 
-Config option B<RCFILE> and B<BASECLASS> are automatically set based
-on the name of command executable.  If you don't want this behavior,
+Config options B<RCFILE> and B<BASECLASS> are automatically set based
+on the name of the command executable.  If you don't want this behavior,
 set B<AUTO_DEFAULT> to 0.
 
 =back
 
 Other options including B<RCFILE> and B<BASECLASS> are passed to
-B<Getopt::EX::Loader>.  Read its document for detail.
+B<Getopt::EX::Loader>.  Read its documentation for details.
 
 =head1 INCOMPATIBILITY
 
-Subroutine B<GetOptionsFromString> is not supported.
+The subroutine B<GetOptionsFromString> is not supported.
 
 =head1 SEE ALSO
 
